@@ -287,7 +287,7 @@ static int parsecfg(xmlDocPtr doc, xmlNodePtr node, struct state *state, unsigne
 		getparam(doc, audio, ioparams_soundcard, par);
 		state->audioio = ioopen_soundcard(&samplerate, mode, par);
 	}
-	if (!state->audioio)
+	if (state->audioio)
                 logprintf(MLOG_FATAL, "cannot start audio\n");
 	for (chan = state->channels; chan; chan = chan->next) {
 		if (chan->demod) {
